@@ -132,5 +132,15 @@ class PostgresRateLimitingRepo(RateLimitingRepo):
 
         return usages
 
+    def drop_old_usages(self, *, until: datetime) -> None:
+        with self._cursor() as cursor:
+            cursor.execute(
+                """
+                DELETE FROM usages
+                WHERE time < %s
+                """,
+                [until],
+            )
+
     def close(self) -> None:
         self._pool.close()
